@@ -5,7 +5,13 @@ from vng_api_common.descriptors import GegevensGroepType
 
 
 class Group(models.Model):
-    pass
+    subgroup_field_1 = models.CharField(max_length=50, blank=True)
+    subgroup_field_2 = models.CharField(max_length=50, blank=True, default="baz")
+
+    subgroup = GegevensGroepType(
+        {"field_1": subgroup_field_1, "field_2": subgroup_field_2},
+        optional=("field_2",),
+    )
 
 
 class Person(models.Model):
